.. :changelog:

Release History
===============

0.1.4
++++++
* Minor fixes

0.1.3
++++++++++++++++++
* Add support for `--expand PolicyEvaluationDetails` to query policy evaluation details on the resource.

0.1.2
++++++++++++++++++
* Minor fixes

0.1.1
++++++++++++++++++

* Add `policy remediation` commands to support resource policy remediation features.

0.1.0
++++++++++++++++++

* Initial Release
